@@ -7,7 +7,7 @@ import { PathExt } from '@jupyterlab/coreutils';
 
 import PauseIcon from '@mui/icons-material/Pause';
 import PlayArrowIcon from '@mui/icons-material/PlayArrow';
-import { IconButton } from '@mui/material';
+import { IconButton, Link } from '@mui/material';
 import Stack from '@mui/material/Stack';
 import TableRow from '@mui/material/TableRow';
 import TableCell from '@mui/material/TableCell';
@@ -91,13 +91,17 @@ export function buildJobDefinitionRow(
   ) => void,
   forceReload: () => void,
   trans: TranslationBundle,
-  ss: SchedulerService
+  ss: SchedulerService,
+  handleApiError: (error: string | null) => void
 ): JSX.Element {
   const cellContents: React.ReactNode[] = [
     // name
-    <a onClick={() => openJobDefinitionDetail(jobDef.job_definition_id)}>
+    <Link
+      onClick={() => openJobDefinitionDetail(jobDef.job_definition_id)}
+      title={`Open detail view for "${jobDef.name}"`}
+    >
       {jobDef.name}
-    </a>,
+    </Link>,
     PathExt.basename(jobDef.input_filename),
     <CreatedAt job={jobDef} />,
     <ScheduleSummary schedule={jobDef.schedule} />,
@@ -106,23 +110,40 @@ export function buildJobDefinitionRow(
       <PauseButton
         jobDef={jobDef}
         clickHandler={async () => {
-          await ss.pauseJobDefinition(jobDef.job_definition_id);
-          forceReload();
+          handleApiError(null);
+          ss.pauseJobDefinition(jobDef.job_definition_id)
+            .then(_ => {
+              forceReload();
+            })
+            .catch((error: Error) => {
+              handleApiError(error.message);
+            });
         }}
       />
       <ResumeButton
         jobDef={jobDef}
         clickHandler={async () => {
-          await ss.resumeJobDefinition(jobDef.job_definition_id);
-          forceReload();
+          handleApiError(null);
+          ss.resumeJobDefinition(jobDef.job_definition_id)
+            .then(_ => {
+              forceReload();
+            })
+            .catch((error: Error) => {
+              handleApiError(error.message);
+            });
         }}
       />
       <ConfirmDeleteButton
         name={jobDef.name}
         clickHandler={async () => {
-          await ss.deleteJobDefinition(jobDef.job_definition_id);
-
-          deleteRow(jobDef.job_definition_id);
+          handleApiError(null);
+          ss.deleteJobDefinition(jobDef.job_definition_id)
+            .then(_ => {
+              deleteRow(jobDef.job_definition_id);
+            })
+            .catch((error: Error) => {
+              handleApiError(error.message);
+            });
         }}
       />
     </Stack>
