@@ -9,7 +9,7 @@ import { useTranslator } from '../hooks';
 import { ICreateJobModel } from '../model';
 import DownloadIcon from '@mui/icons-material/Download';
 import StopIcon from '@mui/icons-material/Stop';
-import { IconButton, Stack, TableCell, TableRow } from '@mui/material';
+import { IconButton, Stack, Link, TableCell, TableRow } from '@mui/material';
 
 function StopButton(props: {
   job: Scheduler.IDescribeJob;
@@ -51,17 +51,17 @@ function JobFiles(props: {
   job: Scheduler.IDescribeJob;
   app: JupyterFrontEnd;
 }): JSX.Element | null {
-  if (props.job.status !== 'COMPLETED') {
+  if (!(props.job.status === 'COMPLETED' || props.job.status === 'FAILED')) {
     return null;
   }
 
   return (
     <>
-      {props.job.job_files.map(jobFile => {
-        return (
-          jobFile.file_path && <JobFileLink jobFile={jobFile} app={props.app} />
-        );
-      })}
+      {props.job.job_files
+        .filter(jobFile => jobFile.file_format !== 'input' && jobFile.file_path)
+        .map(jobFile => (
+          <JobFileLink jobFile={jobFile} app={props.app} />
+        ))}
     </>
   );
 }
@@ -106,13 +106,29 @@ export function buildJobRow(
   showDetailView: (jobId: string) => void,
   reload: () => void
 ): JSX.Element {
+  const inputFile = job.job_files.find(
+    jobFile => jobFile.file_format === 'input' && jobFile.file_path
+  );
+
   const cellContents: React.ReactNode[] = [
-    <a onClick={() => showDetailView(job.job_id)}>{job.name}</a>,
-    job.input_filename,
+    <Link
+      onClick={() => showDetailView(job.job_id)}
+      title={`Open detail view for "${job.name}"`}
+    >
+      {job.name}
+    </Link>,
+    inputFile ? (
+      <JobFileLink app={app} jobFile={inputFile}>
+        {job.input_filename}
+      </JobFileLink>
+    ) : (
+      job.input_filename
+    ),
     <>
-      {!job.downloaded && job.status === 'COMPLETED' && (
-        <DownloadFilesButton app={app} job={job} reload={reload} />
-      )}
+      {!job.downloaded &&
+        (job.status === 'COMPLETED' || job.status === 'FAILED') && (
+          <DownloadFilesButton app={app} job={job} reload={reload} />
+        )}
       <JobFiles job={job} app={app} />
     </>,
     <Timestamp job={job} />,
